@@ -3,58 +3,54 @@
 javaScriptTimerC4 <- function(colourNodePosition,maxScore){
   javaScript<- paste0("
                         ///////////// Count Down Timer Begin ////////////
-                        function countdown( elementName, minutes, seconds )
-                        {
-                        var element, endTime, hours, mins, msLeft, time;
+                      timerHandle = null;
 
-                        function twoDigits( n )
-                        {
-                        return (n <= 9 ? \"0\" + n : n);
-                        }
-                        function updateTimer()
-                        {
-                        msLeft = endTime - (+new Date);
-                        if (msLeft < 10000*6) {
-                        document.getElementById(\"countdown2\").style.color = \"red\";
-                        }
-                        if ( msLeft < 1000 ) {
-                        //element.innerHTML = \"countdown's over!\";
-                        //document.getElementById(\"countdown\");
-                        //document.countdown.submit();
-                        setTimeout('document.countdown2.submit()', 1);
-                        test.submit();
-                        } else {
-                        time = new Date( msLeft );
-                        hours = time.getUTCHours();
-                        mins = time.getUTCMinutes();
-                        element.innerHTML = (hours ? hours + ':' + twoDigits( mins ) : mins) + ':' + twoDigits( time.getUTCSeconds() );
-                        timeStamp =   twoDigits( mins )  + ':' + twoDigits( time.getUTCSeconds()) ;
-                        setTimeout( updateTimer, time.getUTCMilliseconds() + 500 );
-                        }
-                        }
+                      function countdown(minutes, seconds)
+                      {
+                      var endTime, hours, mins, msLeft, time;
 
-                        element = document.getElementById( elementName );
-                        endTime = (+new Date) + 1000 * (60*minutes + seconds) + 500;
-                        updateTimer();
-                        }
+                      function twoDigits(n)
+                      {
+                      return (n <= 9 ? \"0\" + n : n);
+                      }
+                      function updateTimer()
+                      {
+                      msLeft = endTime - (+new Date);
+                      if (msLeft < 10000 * 6) {
+                      document.getElementById(\"countdown2\").style.color = \"white\";
+                      }
+                      if (msLeft < 1000) {
+                      test.submit();
+                      } else {
+                      time = new Date(msLeft);
+                      hours = time.getUTCHours();
+                      mins = time.getUTCMinutes();
+                      document.getElementById(\"countdown\").innerHTML = (hours ? hours + ':' + twoDigits(mins) : mins) + ':' + twoDigits(time.getUTCSeconds());
+                      document.getElementById(\"countdown2\").innerHTML = (hours ? hours + ':' + twoDigits(mins) : mins) + ':' + twoDigits(time.getUTCSeconds());
+                      timeStamp = twoDigits(mins) + ':' + twoDigits(time.getUTCSeconds());
+                      timerHandle = setTimeout(updateTimer, time.getUTCMilliseconds() + 500);
+                      }
+                      }
 
-                        countdown( \"countdown\", 01, 30 );
-                        countdown( \"countdown2\", 01, 30 );
+                      endTime = (+new Date) + 1000 * (60 * minutes + seconds) + 500;
+                      updateTimer();
+                      }
+
+                      countdown(01, 30);
 
 
-                        var pageInput = document.getElementsByTagName(\"input\");
-                        for (i=0; i<pageInput.length; i++){
-                        console.log(pageInput[i]);
-                        pageInput[i].addEventListener('change', function()
-                        {
-                        console.log('test')
-                        document.getElementById(\"submitButton\").disabled = false;
-                        });
-                        }
+                      var pageInput = document.getElementsByTagName(\"input\");
+                      for (i = 0; i < pageInput.length; i++) {
+                      console.log(pageInput[i]);
+                      pageInput[i].addEventListener('change', function ()
+                      {
+                      console.log('test')
+                      document.getElementById(\"submitButton\").disabled = false;
+                      });
+                      }
 
 
-                        ///////////// Timer End ////////////
-
+                      ///////////// Timer End ////////////
                         var isFirstNodeClicked=true;
                         var prevNodeId=null;
                         var nodeArray = [];
@@ -530,49 +526,46 @@ return(javaScript)
 javaScriptTimerC5 <- function(colourNodePosition,maxScore){
   javaScript<- paste0("
                       ///////////// Count Down Timer Begin ////////////
-                      function countdown( elementName, minutes, seconds )
-                      {
-                      var element, endTime, hours, mins, msLeft, time;
+                     timerHandle = null;
 
-                      function twoDigits( n )
+                      function countdown(minutes, seconds)
+                      {
+                      var endTime, hours, mins, msLeft, time;
+
+                      function twoDigits(n)
                       {
                       return (n <= 9 ? \"0\" + n : n);
                       }
                       function updateTimer()
                       {
                       msLeft = endTime - (+new Date);
-                      if (msLeft < 10000*6) {
+                      if (msLeft < 10000 * 6) {
                       document.getElementById(\"countdown2\").style.color = \"red\";
                       }
-                      if ( msLeft < 1000 ) {
-                      //element.innerHTML = \"countdown's over!\";
-                      //document.getElementById(\"countdown\");
-                      //document.countdown.submit();
-                      setTimeout('document.countdown2.submit()', 1);
-                      testRunner.submitView();
+                      if (msLeft < 1000) {
+                      test.submit();
                       } else {
-                      time = new Date( msLeft );
+                      time = new Date(msLeft);
                       hours = time.getUTCHours();
                       mins = time.getUTCMinutes();
-                      element.innerHTML = (hours ? hours + ':' + twoDigits( mins ) : mins) + ':' + twoDigits( time.getUTCSeconds() );
-                      timeStamp =   twoDigits( mins )  + ':' + twoDigits( time.getUTCSeconds()) ;
-                      setTimeout( updateTimer, time.getUTCMilliseconds() + 500 );
+                      document.getElementById(\"countdown\").innerHTML = (hours ? hours + ':' + twoDigits(mins) : mins) + ':' + twoDigits(time.getUTCSeconds());
+                      document.getElementById(\"countdown2\").innerHTML = (hours ? hours + ':' + twoDigits(mins) : mins) + ':' + twoDigits(time.getUTCSeconds());
+                      timeStamp = twoDigits(mins) + ':' + twoDigits(time.getUTCSeconds());
+                      timerHandle = setTimeout(updateTimer, time.getUTCMilliseconds() + 500);
                       }
                       }
 
-                      element = document.getElementById( elementName );
-                      endTime = (+new Date) + 1000 * (60*minutes + seconds) + 500;
+                      endTime = (+new Date) + 1000 * (60 * minutes + seconds) + 500;
                       updateTimer();
                       }
 
-                      countdown( \"countdown\", 01, 30 );
-                      countdown( \"countdown2\", 01, 30 );
+                      countdown(01, 30);
 
 
                       var pageInput = document.getElementsByTagName(\"input\");
-                      for (i=0; i<pageInput.length; i++){
+                      for (i = 0; i < pageInput.length; i++) {
                       console.log(pageInput[i]);
-                      pageInput[i].addEventListener('change', function()
+                      pageInput[i].addEventListener('change', function ()
                       {
                       console.log('test')
                       document.getElementById(\"submitButton\").disabled = false;
@@ -580,6 +573,7 @@ javaScriptTimerC5 <- function(colourNodePosition,maxScore){
                       }
 
 
+
                       ///////////// Timer End ////////////
 
                       var isFirstNodeClicked=true;
@@ -1604,7 +1598,7 @@ javaScript2<- paste0(
   form.appendChild(div);
 
 
-
+ clearTimeout(timerHandle);
   test.submit('next'); // concerto
   return true; // stop the script.
   }
@@ -1631,6 +1625,7 @@ javaScript2<- paste0(
   inputElements5.setAttribute(\"value\", sum);
   div.appendChild(inputElements5);
   form.appendChild(div);
+  clearTimeout(timerHandle);
   test.submit('next'); // concerto
   return true; // stop the script.
 
@@ -1673,7 +1668,7 @@ javaScriptTwoC5 <-function(finalRow){
     form.appendChild(div);
 
 
-
+    clearTimeout(timerHandle);
     testRunner.submitView('next'); // concerto
     return true; // stop the script.
 }
@@ -1700,6 +1695,7 @@ inputElements4.setAttribute(\"value\", 0);
   inputElements5.setAttribute(\"value\", sum);
   div.appendChild(inputElements5);
   form.appendChild(div);
+  clearTimeout(timerHandle);
   testRunner.submitView('next'); // concerto
   return true; // stop the script.
 
